@@ -28,6 +28,7 @@ class Redmine(object):
         self.date_format = kwargs.get('date_format', '%Y-%m-%d')
         self.datetime_format = kwargs.get('datetime_format', '%Y-%m-%dT%H:%M:%SZ')
         self.raise_attr_exception = kwargs.get('raise_attr_exception', True)
+        self.custom_resource_paths = kwargs.get('custom_resource_paths', None)
 
     def __getattr__(self, resource):
         """Returns either ResourceSet or Resource object depending on the method used on the ResourceManager"""
@@ -71,7 +72,7 @@ class Redmine(object):
         response = getattr(requests, method)(url, **kwargs)
 
         if response.status_code in (200, 201):
-            if response.status_code == 200 and method in ('put', 'delete'):
+            if not response.content:
                 return True
             return response.json()
         elif response.status_code == 401:
