@@ -1,7 +1,13 @@
 from datetime import datetime
+from distutils.version import LooseVersion
 from redmine.utilities import to_string
 from redmine.managers import ResourceManager
-from redmine.exceptions import ResourceAttrError, ReadonlyAttrError, CustomFieldValueError
+from redmine.exceptions import (
+    ResourceAttrError,
+    ReadonlyAttrError,
+    CustomFieldValueError,
+    ResourceVersionMismatchError
+)
 
 # Resources which when accessed from some other
 # resource should become a ResourceSet object
@@ -93,7 +99,7 @@ class _Resource(object):
     _changes = {}
     _includes = ()
     _relations = ()
-    _readonly = ('id', 'created_on', 'updated_on', 'author', 'user', 'project', 'issue')
+    _readonly = ('id', 'created_on', 'updated_on', 'author', 'user', 'project', 'issue')  #: Read-only attributes
     __length_hint__ = None  # fixes Python 2.6 list() call on resource object
 
     def __init__(self, manager, attributes):
@@ -299,9 +305,30 @@ class Issue(_Resource):
     _relations = ('relations', 'time_entries')
     _readonly = _Resource._readonly + ('spent_hours',)
 
+    class Watcher:
+        """An issue watcher implementation"""
+        def __init__(self, issue):
+            self._redmine = issue.manager.redmine
+            self._issue_id = issue.internal_id
+
+            if self._redmine.ver is not None and LooseVersion(str(self._redmine.ver)) < LooseVersion('2.3'):
+                raise ResourceVersionMismatchError()
+
+        def add(self, user_id):
+            """Adds user to issue watchers list"""
+            url = '{0}/issues/{1}/watchers.json'.format(self._redmine.url, self._issue_id)
+            return self._redmine.request('post', url, data={'user_id': user_id})
+
+        def remove(self, user_id):
+            """Removes user from issue watchers list"""
+            url = '{0}/issues/{1}/watchers/{2}.json'.format(self._redmine.url, self._issue_id, user_id)
+            return self._redmine.request('delete', url)
+
     def __getattr__(self, item):
         if item == 'version':
             return super(Issue, self).__getattr__('fixed_version')
+        elif item == 'watcher':
+            return Issue.Watcher(self)
 
         return super(Issue, self).__getattr__(item)
 
@@ -575,6 +602,28 @@ class Group(_Resource):
 
     _includes = ('memberships', 'users')
 
+    class User:
+        """A group user implementation"""
+        def __init__(self, group):
+            self._redmine = group.manager.redmine
+            self._group_id = group.internal_id
+
+        def add(self, user_id):
+            """Adds user to a group"""
+            url = '{0}/groups/{1}/users.json'.format(self._redmine.url, self._group_id)
+            return self._redmine.request('post', url, data={'user_id': user_id})
+
+        def remove(self, user_id):
+            """Removes user from a group"""
+            url = '{0}/groups/{1}/users/{2}.json'.format(self._redmine.url, self._group_id, user_id)
+            return self._redmine.request('delete', url)
+
+    def __getattr__(self, item):
+        if item == 'user':
+            return Group.User(self)
+
+        return super(Group, self).__getattr__(item)
+
 
 class Role(_Resource):
     redmine_version = '1.4'
